@@ -42,7 +42,7 @@
 #define _UNUSED_PARAMETER_
 #include <unistr.h>
 #include <unicase.h>
-#elif HAVE_LIBICU
+#elif defined(HAVE_LIBICU)
 #include <unicode/utypes.h>
 #include <unicode/uregex.h>
 #include <unicode/ustring.h>
@@ -893,7 +893,7 @@ function_sparql_unaccent (sqlite3_context *context,
 	sqlite3_result_text (context, zOutput, written, free);
 }
 
-#elif HAVE_LIBICU
+#elif defined(HAVE_LIBICU)
 
 static void
 function_sparql_lower_case (sqlite3_context *context,
@@ -1580,6 +1580,7 @@ close_database (TrackerDBInterface *db_interface)
 	}
 }
 
+#if HAVE_TRACKER_FTS
 static gchar **
 _fts_create_properties (GHashTable *properties)
 {
@@ -1607,6 +1608,7 @@ _fts_create_properties (GHashTable *properties)
 
 	return (gchar **) g_ptr_array_free (cols, FALSE);
 }
+#endif
 
 void
 tracker_db_interface_sqlite_fts_init (TrackerDBInterface  *db_interface,
@@ -1647,6 +1649,14 @@ tracker_db_interface_sqlite_fts_init (TrackerDBInterface  *db_interface,
 
 #if HAVE_TRACKER_FTS
 
+void
+tracker_db_interface_sqlite_fts_delete_table (TrackerDBInterface  *db_interface)
+{
+	if (!tracker_fts_delete_table (db_interface->db, "fts5")) {
+		g_critical ("Failed to delete FTS table");
+	}
+}
+
 void
 tracker_db_interface_sqlite_fts_alter_table (TrackerDBInterface  *db_interface,
 					     GHashTable          *properties,
