@@ -444,7 +444,9 @@ file_notifier_add_node_foreach (GNode    *node,
 
 		g_object_unref (file_info);
 
-		if (file_type == G_FILE_TYPE_DIRECTORY && !G_NODE_IS_ROOT (node)) {
+		if (file_type == G_FILE_TYPE_DIRECTORY &&
+		    (priv->current_index_root->flags & TRACKER_DIRECTORY_FLAG_RECURSE) != 0 &&
+		    !G_NODE_IS_ROOT (node)) {
 			/* Queue child dirs for later processing */
 			g_assert (node->children == NULL);
 			g_queue_push_tail (priv->current_index_root->pending_dirs,
@@ -2100,10 +2102,7 @@ tracker_file_notifier_invalidate_file_iri (TrackerFileNotifier *notifier,
 	g_return_if_fail (G_IS_FILE (file));
 
 	priv = notifier->priv;
-	canonical = tracker_file_system_get_file (priv->file_system,
-	                                          file,
-	                                          G_FILE_TYPE_REGULAR,
-	                                          NULL);
+	canonical = tracker_file_system_peek_file (priv->file_system, file);
 	if (!canonical) {
 		return;
 	}
