@@ -20,14 +20,13 @@
 """
 Send concurrent inserts and queries to the daemon to check the concurrency.
 """
-import sys,os,dbus
+import sys,os
 import unittest
 import time
 import random
 import commands
 import signal
 from gi.repository import GObject
-from dbus.mainloop.glib import DBusGMainLoop
 
 from common.utils import configuration as cfg
 import unittest2 as ut
@@ -73,29 +72,31 @@ class TestConcurrentQuery (CommonTrackerStoreTest):
         QUERY = "SELECT ?u WHERE { ?u a nco:PersonContact. FILTER regex (?u, 'test-09:ins')}"
         UPDATE = "INSERT { <test-09:picture-%d> a nmm:Photo. }"
         for i in range (0, AMOUNT_OF_QUERIES):
-            self.tracker.get_tracker_iface ().SparqlQuery (QUERY,
-                                                           reply_handler=self.reply_cb,
-                                                           error_handler=self.error_handler)
-            self.tracker.get_tracker_iface ().SparqlUpdate (UPDATE % (i),
-                                                            reply_handler=self.update_cb,
-                                                            error_handler=self.error_handler)
-            
+            self.tracker.query(
+                QUERY,
+                result_handler=self.reply_cb,
+                error_handler=self.error_handler)
+            self.tracker.update(
+                UPDATE % (i),
+                result_handler=self.update_cb,
+                error_handler=self.error_handler)
+
         # Safeguard of 50 seconds. The last reply should quit the loop
         GObject.timeout_add_seconds (60, self.timeout_cb)
         self.main_loop.run ()
         
-    def reply_cb (self, results):
+    def reply_cb (self, obj, results, data):
         self.finish_counter += 1
         self.assertEquals (len (results), AMOUNT_OF_TEST_INSTANCES)
         if (self.finish_counter >= AMOUNT_OF_QUERIES):
             self.timeout_cb ()
 
-    def update_cb (self):
+    def update_cb (self, obj, results, data):
         self.assertTrue (True)
 
-    def error_handler (self):
-        print "ERROR in DBus call"
-        self.assertTrue (False)
+    def error_handler (self, obj, e, user_data):
+        print "ERROR in DBus call: %s" % e
+        raise(e)
 
     def timeout_cb (self):
         self.mock_data_delete ()
