@@ -159,9 +159,11 @@ main (int argc, char **argv)
 	setlocale (LC_COLLATE, "en_US.utf8");
 
 	current_dir = g_get_current_dir ();
-	tests_data_dir = g_build_path (G_DIR_SEPARATOR_S, current_dir, "test-data", NULL);
+	tests_data_dir = g_build_path (G_DIR_SEPARATOR_S, current_dir, "sparql-blank-test-data-XXXXXX", NULL);
 	g_free (current_dir);
 
+	g_mkdtemp (tests_data_dir);
+
 	g_test_init (&argc, &argv, NULL);
 	g_test_add ("/libtracker-data/sparql-blank", TestInfo, NULL, setup, test_blank, teardown);
 
